@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 #include <algorithm>
 #include <iostream>
 #include <vector>
+#include <glib/gi18n.h>
 
 #include "gm-cell-renderer-bitext.h"
 #include "gmcellrendererexpander.h"
@@ -140,20 +141,20 @@ static void remove_child (GtkWidget* child,
 /* DESCRIPTION : Set of functions called when the user clicks in a view
  * BEHAVIOUR   : Folds/unfolds, shows a menu or triggers default action
  */
-static void on_clicked_show_heap_menu (Ekiga::Heap* heap,
+static void on_clicked_show_heap_menu (gmref_ptr<Ekiga::Heap> heap,
 				       GdkEventButton* event);
-static void on_clicked_show_heap_group_menu (Ekiga::Heap* heap,
+static void on_clicked_show_heap_group_menu (gmref_ptr<Ekiga::Heap> heap,
 					     const std::string name,
 					     GdkEventButton* event);
-static void on_clicked_show_presentity_menu (Ekiga::Heap* heap,
-					     Ekiga::Presentity* presentity,
+static void on_clicked_show_presentity_menu (gmref_ptr<Ekiga::Heap> heap,
+					     gmref_ptr<Ekiga::Presentity> presentity,
 					     GdkEventButton* event);
 
 static void on_clicked_fold (RosterViewGtk* self,
 			     GtkTreePath* path,
 			     const gchar* name);
 
-static void on_clicked_trigger_presentity (Ekiga::Presentity* presentity);
+static void on_clicked_trigger_presentity (gmref_ptr<Ekiga::Presentity> presentity);
 
 /* DESCRIPTION : Called whenever a (online/total) count has to be updated
  * BEHAVIOUR   : Updates things...
@@ -182,9 +183,9 @@ static void on_selection_changed (GtkTreeSelection* selection,
  * BEHAVIOR     : Update the menu and displays it as a popup.
  * PRE          : The gpointer must point to the RosterViewGtk GObject.
  */
-static gint on_view_clicked (GtkWidget *tree_view,
-			     GdkEventButton *event,
-			     gpointer data);
+static gint on_view_event_after (GtkWidget *tree_view,
+			         GdkEventButton *event,
+			         gpointer data);
 
 /* DESCRIPTION : Helpers for the next function
  */
@@ -238,7 +239,7 @@ static void expand_cell_data_func (GtkTreeViewColumn *column,
  * BEHAVIOR     : Visits the cluster's heaps, and add them to the view
  * PRE          : /
  */
-static void on_cluster_added (Ekiga::Cluster &cluster,
+static void on_cluster_added (gmref_ptr<Ekiga::Cluster> cluster,
 			      gpointer data);
 
 
@@ -246,24 +247,24 @@ static void on_cluster_added (Ekiga::Cluster &cluster,
  * BEHAVIOR     : Adds in the cluster heaps
  * PRE          : /
  */
-static bool visit_heaps (Ekiga::Heap &heap,
-			 Ekiga::Cluster *cluster,
+static bool visit_heaps (gmref_ptr<Ekiga::Heap> heap,
+			 gmref_ptr<Ekiga::Cluster> cluster,
 			 gpointer data);
 
 /* DESCRIPTION  : Called when the or heap_added signal has been emitted
  * BEHAVIOR     : Add or Update the Heap in the GtkTreeView.
  * PRE          : /
  */
-static void on_heap_added (Ekiga::Cluster &cluster,
-			   Ekiga::Heap &heap,
+static void on_heap_added (gmref_ptr<Ekiga::Cluster> cluster,
+			   gmref_ptr<Ekiga::Heap> heap,
 			   gpointer data);
 
 /* DESCRIPTION  : Called when the heap_updated signal has been emitted
  * BEHAVIOR     : Add or Update the Heap in the GtkTreeView.
  * PRE          : /
  */
-static void on_heap_updated (Ekiga::Cluster &cluster,
-			     Ekiga::Heap &heap,
+static void on_heap_updated (gmref_ptr<Ekiga::Cluster> cluster,
+			     gmref_ptr<Ekiga::Heap> heap,
 			     gpointer data);
 
 
@@ -274,8 +275,8 @@ static void on_heap_updated (Ekiga::Cluster &cluster,
  *                the view.
  * PRE          : /
  */
-static void on_heap_removed (Ekiga::Cluster &cluster,
-			     Ekiga::Heap &heap,
+static void on_heap_removed (gmref_ptr<Ekiga::Cluster> cluster,
+			     gmref_ptr<Ekiga::Heap> heap,
 			     gpointer data);
 
 
@@ -283,9 +284,9 @@ static void on_heap_removed (Ekiga::Cluster &cluster,
  * BEHAVIOR     : Adds in the heap presentities
  * PRE          : /
  */
-static bool visit_presentities (Ekiga::Presentity &presentity,
-				Ekiga::Cluster *cluster,
-				Ekiga::Heap *heap,
+static bool visit_presentities (gmref_ptr<Ekiga::Presentity> presentity,
+				gmref_ptr<Ekiga::Cluster> cluster,
+				gmref_ptr<Ekiga::Heap> heap,
 				gpointer data);
 
 
@@ -295,9 +296,9 @@ static bool visit_presentities (Ekiga::Presentity &presentity,
  *                added.
  * PRE          : A valid Heap.
  */
-static void on_presentity_added (Ekiga::Cluster &cluster,
-				 Ekiga::Heap &heap,
-				 Ekiga::Presentity &presentity,
+static void on_presentity_added (gmref_ptr<Ekiga::Cluster> cluster,
+				 gmref_ptr<Ekiga::Heap> heap,
+				 gmref_ptr<Ekiga::Presentity> presentity,
 				 gpointer data);
 
 
@@ -306,9 +307,9 @@ static void on_presentity_added (Ekiga::Cluster &cluster,
  * BEHAVIOR     : Update the given Presentity into the Heap.
  * PRE          : A valid Heap.
  */
-static void on_presentity_updated (Ekiga::Cluster &cluster,
-				   Ekiga::Heap &heap,
-				   Ekiga::Presentity &presentity,
+static void on_presentity_updated (gmref_ptr<Ekiga::Cluster> cluster,
+				   gmref_ptr<Ekiga::Heap> heap,
+				   gmref_ptr<Ekiga::Presentity> presentity,
 				   gpointer data);
 
 
@@ -317,9 +318,9 @@ static void on_presentity_updated (Ekiga::Cluster &cluster,
  * BEHAVIOR     : Remove the given Presentity from the given Heap.
  * PRE          : A valid Heap.
  */
-static void on_presentity_removed (Ekiga::Cluster &cluster,
-				   Ekiga::Heap &heap,
-				   Ekiga::Presentity &presentity,
+static void on_presentity_removed (gmref_ptr<Ekiga::Cluster> cluster,
+				   gmref_ptr<Ekiga::Heap> heap,
+				   gmref_ptr<Ekiga::Presentity> presentity,
 				   gpointer data);
 
 
@@ -341,7 +342,7 @@ static bool on_handle_questions (Ekiga::FormRequest *request,
  * PRE          : /
  */
 static void roster_view_gtk_find_iter_for_heap (RosterViewGtk *view,
-                                                Ekiga::Heap &heap,
+                                                gmref_ptr<Ekiga::Heap> heap,
                                                 GtkTreeIter *iter);
 
 
@@ -352,7 +353,7 @@ static void roster_view_gtk_find_iter_for_heap (RosterViewGtk *view,
  * PRE          : /
  */
 static void roster_view_gtk_find_iter_for_group (RosterViewGtk *view,
-						 Ekiga::Heap& heap,
+						 gmref_ptr<Ekiga::Heap> heap,
                                                  GtkTreeIter *heap_iter,
                                                  const std::string name,
                                                  GtkTreeIter *iter);
@@ -366,7 +367,7 @@ static void roster_view_gtk_find_iter_for_group (RosterViewGtk *view,
  */
 static void roster_view_gtk_find_iter_for_presentity (RosterViewGtk *view,
                                                       GtkTreeIter *group_iter,
-                                                      Ekiga::Presentity &presentity,
+                                                      gmref_ptr<Ekiga::Presentity> presentity,
                                                       GtkTreeIter *iter);
 
 
@@ -391,7 +392,7 @@ remove_child (GtkWidget* child,
 }
 
 static void
-on_clicked_show_heap_menu (Ekiga::Heap* heap,
+on_clicked_show_heap_menu (gmref_ptr<Ekiga::Heap> heap,
 			   GdkEventButton* event)
 {
   MenuBuilderGtk builder;
@@ -402,14 +403,14 @@ on_clicked_show_heap_menu (Ekiga::Heap* heap,
     gtk_menu_popup (GTK_MENU (builder.menu), NULL, NULL,
 		    NULL, NULL, event->button, event->time);
     g_signal_connect (G_OBJECT (builder.menu), "hide",
-		      GTK_SIGNAL_FUNC (g_object_unref),
+		      G_CALLBACK (g_object_unref),
 		      (gpointer) builder.menu);
   }
   g_object_ref_sink (G_OBJECT (builder.menu));
 }
 
 static void
-on_clicked_show_heap_group_menu (Ekiga::Heap* heap,
+on_clicked_show_heap_group_menu (gmref_ptr<Ekiga::Heap> heap,
 				 const std::string name,
 				 GdkEventButton* event)
 {
@@ -421,15 +422,15 @@ on_clicked_show_heap_group_menu (Ekiga::Heap* heap,
     gtk_menu_popup (GTK_MENU (builder.menu), NULL, NULL,
 		    NULL, NULL, event->button, event->time);
     g_signal_connect (G_OBJECT (builder.menu), "hide",
-		      GTK_SIGNAL_FUNC (g_object_unref),
+		      G_CALLBACK (g_object_unref),
 		      (gpointer) builder.menu);
   }
   g_object_ref_sink (G_OBJECT (builder.menu));
 }
 
 static void
-on_clicked_show_presentity_menu (Ekiga::Heap* heap,
-				 Ekiga::Presentity* presentity,
+on_clicked_show_presentity_menu (gmref_ptr<Ekiga::Heap> heap,
+				 gmref_ptr<Ekiga::Presentity> presentity,
 				 GdkEventButton* event)
 {
   Ekiga::TemporaryMenuBuilder temp;
@@ -449,7 +450,7 @@ on_clicked_show_presentity_menu (Ekiga::Heap* heap,
     gtk_menu_popup (GTK_MENU (builder.menu), NULL, NULL,
 		    NULL, NULL, event->button, event->time);
     g_signal_connect (G_OBJECT (builder.menu), "hide",
-		      GTK_SIGNAL_FUNC (g_object_unref),
+		      G_CALLBACK (g_object_unref),
 		      (gpointer) builder.menu);
   }
   g_object_ref_sink (G_OBJECT (builder.menu));
@@ -493,7 +494,7 @@ on_clicked_fold (RosterViewGtk* self,
 }
 
 static void
-on_clicked_trigger_presentity (Ekiga::Presentity* presentity)
+on_clicked_trigger_presentity (gmref_ptr<Ekiga::Presentity> presentity)
 {
   Ekiga::TriggerMenuBuilder builder;
 
@@ -659,15 +660,18 @@ on_selection_changed (GtkTreeSelection* selection,
 }
 
 static gint
-on_view_clicked (GtkWidget *tree_view,
-		 GdkEventButton *event,
-		 gpointer data)
+on_view_event_after (GtkWidget *tree_view,
+		     GdkEventButton *event,
+		     gpointer data)
 {
   RosterViewGtk *self = NULL;
   GtkTreeModel *model = NULL;
   GtkTreePath *path = NULL;
   GtkTreeIter iter;
 
+  if (event->type != GDK_BUTTON_PRESS && event->type != GDK_2BUTTON_PRESS)
+    return FALSE;
+
   self = ROSTER_VIEW_GTK (data);
   model = gtk_tree_view_get_model (self->priv->tree_view);
 
@@ -695,24 +699,28 @@ on_view_clicked (GtkWidget *tree_view,
 	if (event->type == GDK_BUTTON_PRESS && event->button == 1 && name)
 	  on_clicked_fold (self, path, name);
 	if (event->type == GDK_BUTTON_PRESS && event->button == 3)
-	  on_clicked_show_heap_menu (heap, event);
+	  on_clicked_show_heap_menu (gmref_ptr<Ekiga::Heap>(heap), event);
 	break;
       case TYPE_GROUP:
 
 	if (event->type == GDK_BUTTON_PRESS && event->button == 1 && name)
 	  on_clicked_fold (self, path, name);
 	if (event->type == GDK_BUTTON_PRESS && event->button == 3)
-	  on_clicked_show_heap_group_menu (heap, name, event);
+	  on_clicked_show_heap_group_menu (gmref_ptr<Ekiga::Heap>(heap),
+					   name, event);
 	break;
       case TYPE_PRESENTITY:
 
 	if (event->type == GDK_BUTTON_PRESS && event->button == 3)
-	  on_clicked_show_presentity_menu (heap, presentity, event);
+	  on_clicked_show_presentity_menu (gmref_ptr<Ekiga::Heap>(heap),
+					   gmref_ptr<Ekiga::Presentity>(presentity),
+					   event);
 	if (event->type == GDK_2BUTTON_PRESS)
-	  on_clicked_trigger_presentity (presentity);
+	  on_clicked_trigger_presentity (gmref_ptr<Ekiga::Presentity>(presentity));
 	break;
       default:
 
+	g_assert_not_reached ();
 	break; // shouldn't happen
       }
       g_free (name);
@@ -865,36 +873,36 @@ expand_cell_data_func (GtkTreeViewColumn *column,
 }
 
 static void
-on_cluster_added (Ekiga::Cluster &cluster,
+on_cluster_added (gmref_ptr<Ekiga::Cluster> cluster,
 		  gpointer data)
 {
-  cluster.visit_heaps (sigc::bind (sigc::ptr_fun (visit_heaps),
-				   &cluster, data));
+  cluster->visit_heaps (sigc::bind (sigc::ptr_fun (visit_heaps),
+				    cluster, data));
 }
 
 static bool
-visit_heaps (Ekiga::Heap &heap,
-	     Ekiga::Cluster *cluster,
+visit_heaps (gmref_ptr<Ekiga::Heap> heap,
+	     gmref_ptr<Ekiga::Cluster> cluster,
 	     gpointer data)
 {
-  on_heap_updated (*cluster, heap, data);
-  heap.visit_presentities (sigc::bind (sigc::ptr_fun (visit_presentities), cluster, &heap, data));
+  on_heap_updated (cluster, heap, data);
+  heap->visit_presentities (sigc::bind (sigc::ptr_fun (visit_presentities), cluster, heap, data));
 
   return true;
 }
 
 static void
-on_heap_added (Ekiga::Cluster &cluster,
-	       Ekiga::Heap &heap,
+on_heap_added (gmref_ptr<Ekiga::Cluster> cluster,
+	       gmref_ptr<Ekiga::Heap> heap,
 	       gpointer data)
 {
   on_heap_updated (cluster, heap, data);
-  heap.visit_presentities (sigc::bind (sigc::ptr_fun (visit_presentities), &cluster, &heap, data));
+  heap->visit_presentities (sigc::bind (sigc::ptr_fun (visit_presentities), cluster, heap, data));
 }
 
 static void
-on_heap_updated (Ekiga::Cluster &/*cluster*/,
-		 Ekiga::Heap &heap,
+on_heap_updated (gmref_ptr<Ekiga::Cluster> /*cluster*/,
+		 gmref_ptr<Ekiga::Heap> heap,
 		 gpointer data)
 {
   RosterViewGtk *self = ROSTER_VIEW_GTK (data);
@@ -904,16 +912,16 @@ on_heap_updated (Ekiga::Cluster &/*cluster*/,
 
   gtk_tree_store_set (self->priv->store, &iter,
 		      COLUMN_TYPE, TYPE_HEAP,
-		      COLUMN_HEAP, &heap,
-		      COLUMN_NAME, heap.get_name ().c_str (),
+		      COLUMN_HEAP, &*heap,
+		      COLUMN_NAME, heap->get_name ().c_str (),
 		      -1);
   gtk_tree_view_expand_all (self->priv->tree_view);
 }
 
 
 static void
-on_heap_removed (Ekiga::Cluster &/*cluster*/,
-		 Ekiga::Heap &heap,
+on_heap_removed (gmref_ptr<Ekiga::Cluster> /*cluster*/,
+		 gmref_ptr<Ekiga::Heap> heap,
 		 gpointer data)
 {
   RosterViewGtk *self = ROSTER_VIEW_GTK (data);
@@ -926,25 +934,25 @@ on_heap_removed (Ekiga::Cluster &/*cluster*/,
 
 
 static bool
-visit_presentities (Ekiga::Presentity &presentity,
-		    Ekiga::Cluster *cluster,
-		    Ekiga::Heap *heap,
+visit_presentities (gmref_ptr<Ekiga::Presentity> presentity,
+		    gmref_ptr<Ekiga::Cluster> cluster,
+		    gmref_ptr<Ekiga::Heap> heap,
 		    gpointer data)
 {
-  on_presentity_added (*cluster, *heap, presentity, data);
+  on_presentity_added (cluster, heap, presentity, data);
 
   return true;
 }
 
 static void
-on_presentity_added (Ekiga::Cluster &/*cluster*/,
-		     Ekiga::Heap &heap,
-		     Ekiga::Presentity &presentity,
+on_presentity_added (gmref_ptr<Ekiga::Cluster> /*cluster*/,
+		     gmref_ptr<Ekiga::Heap> heap,
+		     gmref_ptr<Ekiga::Presentity> presentity,
 		     gpointer data)
 {
   RosterViewGtk *self = ROSTER_VIEW_GTK (data);
   GtkTreeIter heap_iter;
-  std::set<std::string> groups = presentity.get_groups ();
+  std::set<std::string> groups = presentity->get_groups ();
   GtkTreeIter group_iter;
   GtkTreeIter iter;
   bool active = false;
@@ -952,8 +960,8 @@ on_presentity_added (Ekiga::Cluster &/*cluster*/,
 
   roster_view_gtk_find_iter_for_heap (self, heap, &heap_iter);
 
-  active = presentity.get_presence () != "offline";
-  away = presentity.get_presence () == "away";
+  active = presentity->get_presence () != "offline";
+  away = presentity->get_presence () == "away";
 
   for (std::set<std::string>::const_iterator group = groups.begin ();
        group != groups.end ();
@@ -966,11 +974,11 @@ on_presentity_added (Ekiga::Cluster &/*cluster*/,
     gtk_tree_store_set (self->priv->store, &iter,
 			COLUMN_TYPE, TYPE_PRESENTITY,
 			COLUMN_OFFLINE, active,
-			COLUMN_HEAP, &heap,
-			COLUMN_PRESENTITY, &presentity,
-			COLUMN_NAME, presentity.get_name ().c_str (),
-			COLUMN_STATUS, presentity.get_status ().c_str (),
-			COLUMN_PRESENCE, presentity.get_presence ().c_str (),
+			COLUMN_HEAP, &*heap,
+			COLUMN_PRESENTITY, &*presentity,
+			COLUMN_NAME, presentity->get_name ().c_str (),
+			COLUMN_STATUS, presentity->get_status ().c_str (),
+			COLUMN_PRESENCE, presentity->get_presence ().c_str (),
 			COLUMN_ACTIVE, (!active || away) ? "gray" : "black",
 			-1);
   }
@@ -983,11 +991,11 @@ on_presentity_added (Ekiga::Cluster &/*cluster*/,
     gtk_tree_store_set (self->priv->store, &iter,
 			COLUMN_TYPE, TYPE_PRESENTITY,
 			COLUMN_OFFLINE, active,
-			COLUMN_HEAP, &heap,
-			COLUMN_PRESENTITY, &presentity,
-			COLUMN_NAME, presentity.get_name ().c_str (),
-			COLUMN_STATUS, presentity.get_status ().c_str (),
-			COLUMN_PRESENCE, presentity.get_presence ().c_str (),
+			COLUMN_HEAP, &*heap,
+			COLUMN_PRESENTITY, &*presentity,
+			COLUMN_NAME, presentity->get_name ().c_str (),
+			COLUMN_STATUS, presentity->get_status ().c_str (),
+			COLUMN_PRESENCE, presentity->get_presence ().c_str (),
 			COLUMN_ACTIVE, active ? "black" : "gray",
 			-1);
   }
@@ -997,9 +1005,9 @@ on_presentity_added (Ekiga::Cluster &/*cluster*/,
 
 
 static void
-on_presentity_updated (Ekiga::Cluster &cluster,
-		       Ekiga::Heap &heap,
-		       Ekiga::Presentity &presentity,
+on_presentity_updated (gmref_ptr<Ekiga::Cluster> cluster,
+		       gmref_ptr<Ekiga::Heap> heap,
+		       gmref_ptr<Ekiga::Presentity> presentity,
 		       gpointer data)
 {
   RosterViewGtk *self = (RosterViewGtk *)data;
@@ -1008,7 +1016,7 @@ on_presentity_updated (Ekiga::Cluster &cluster,
   GtkTreeIter group_iter;
   GtkTreeIter iter;
   gchar *group_name = NULL;
-  std::set<std::string> groups = presentity.get_groups ();
+  std::set<std::string> groups = presentity->get_groups ();
 
   model = GTK_TREE_MODEL (self->priv->store);
 
@@ -1045,9 +1053,9 @@ on_presentity_updated (Ekiga::Cluster &cluster,
 
 
 static void
-on_presentity_removed (Ekiga::Cluster &/*cluster*/,
-		       Ekiga::Heap &heap,
-		       Ekiga::Presentity &presentity,
+on_presentity_removed (gmref_ptr<Ekiga::Cluster> /*cluster*/,
+		       gmref_ptr<Ekiga::Heap> heap,
+		       gmref_ptr<Ekiga::Presentity> presentity,
 		       gpointer data)
 {
   RosterViewGtk *self = ROSTER_VIEW_GTK (data);
@@ -1089,7 +1097,7 @@ on_handle_questions (Ekiga::FormRequest *request,
  */
 static void
 roster_view_gtk_find_iter_for_heap (RosterViewGtk *view,
-                                    Ekiga::Heap &heap,
+                                    gmref_ptr<Ekiga::Heap> heap,
                                     GtkTreeIter *iter)
 {
   GtkTreeModel *model = NULL;
@@ -1103,7 +1111,7 @@ roster_view_gtk_find_iter_for_heap (RosterViewGtk *view,
     do {
 
       gtk_tree_model_get (model, iter, COLUMN_HEAP, &iter_heap, -1);
-      if (iter_heap == &heap)
+      if (iter_heap == &*heap)
 	found = TRUE;
     } while (!found && gtk_tree_model_iter_next (model, iter));
   }
@@ -1115,7 +1123,7 @@ roster_view_gtk_find_iter_for_heap (RosterViewGtk *view,
 
 static void
 roster_view_gtk_find_iter_for_group (RosterViewGtk *view,
-				     Ekiga::Heap& heap,
+				     gmref_ptr<Ekiga::Heap> heap,
                                      GtkTreeIter *heap_iter,
                                      const std::string name,
                                      GtkTreeIter *iter)
@@ -1143,7 +1151,7 @@ roster_view_gtk_find_iter_for_group (RosterViewGtk *view,
     gtk_tree_store_append (view->priv->store, iter, heap_iter);
     gtk_tree_store_set (view->priv->store, iter,
                         COLUMN_TYPE, TYPE_GROUP,
-			COLUMN_HEAP, &heap,
+			COLUMN_HEAP, &*heap,
                         COLUMN_NAME, name.c_str (),
                         -1);
   }
@@ -1153,7 +1161,7 @@ roster_view_gtk_find_iter_for_group (RosterViewGtk *view,
 static void
 roster_view_gtk_find_iter_for_presentity (RosterViewGtk *view,
                                           GtkTreeIter *group_iter,
-                                          Ekiga::Presentity &presentity,
+                                          gmref_ptr<Ekiga::Presentity> presentity,
                                           GtkTreeIter *iter)
 {
   GtkTreeModel *model = NULL;
@@ -1167,7 +1175,7 @@ roster_view_gtk_find_iter_for_presentity (RosterViewGtk *view,
     do {
 
       gtk_tree_model_get (model, iter, COLUMN_PRESENTITY, &iter_presentity, -1);
-      if (iter_presentity == &presentity)
+      if (iter_presentity == &*presentity)
 	found = TRUE;
     } while (!found && gtk_tree_model_iter_next (model, iter));
   }
@@ -1252,6 +1260,12 @@ roster_view_gtk_dispose (GObject *obj)
 
   view = ROSTER_VIEW_GTK (obj);
 
+  for (std::vector<sigc::connection>::iterator iter
+	 = view->priv->connections.begin ();
+       iter != view->priv->connections.end ();
+       iter++)
+    iter->disconnect ();
+
   if (view->priv->tree_view) {
 
     g_signal_handlers_disconnect_matched (gtk_tree_view_get_selection (view->priv->tree_view),
@@ -1282,12 +1296,6 @@ roster_view_gtk_finalize (GObject *obj)
 
   view = (RosterViewGtk *)obj;
 
-  for (std::vector<sigc::connection>::iterator iter
-	 = view->priv->connections.begin ();
-       iter != view->priv->connections.end ();
-       iter++)
-    iter->disconnect ();
-
   delete view->priv;
 
   parent_class->finalize (obj);
@@ -1407,15 +1415,15 @@ roster_view_gtk_new (Ekiga::PresenceCore &core)
 				  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
   self->priv->store = gtk_tree_store_new (COLUMN_NUMBER,
-                                          G_TYPE_INT,       // type
-                                          G_TYPE_POINTER,   // heap
-                                          G_TYPE_POINTER,   // presentity
-                                          G_TYPE_STRING,    // name
-                                          G_TYPE_STRING,    // status
-                                          G_TYPE_STRING,    // presence
-                                          G_TYPE_STRING,    // color if active
-					  G_TYPE_STRING,    // group size
-					  G_TYPE_BOOLEAN);  // offline
+                                          G_TYPE_INT,         // type
+                                          G_TYPE_POINTER,     // heap
+                                          G_TYPE_POINTER,     // presentity
+                                          G_TYPE_STRING,      // name
+                                          G_TYPE_STRING,      // status
+                                          G_TYPE_STRING,      // presence
+                                          G_TYPE_STRING,      // color if active
+					  G_TYPE_STRING,      // group size
+					  G_TYPE_BOOLEAN);    // offline
 
   gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (self->priv->store),
                                         COLUMN_NAME, GTK_SORT_ASCENDING);
@@ -1512,31 +1520,31 @@ roster_view_gtk_new (Ekiga::PresenceCore &core)
   g_signal_connect (G_OBJECT (selection), "changed",
 		    G_CALLBACK (on_selection_changed), self);
   g_signal_connect (G_OBJECT (self->priv->tree_view), "event-after",
-		    G_CALLBACK (on_view_clicked), self);
+		    G_CALLBACK (on_view_event_after), self);
 
 
   /* Relay signals */
   conn = core.cluster_added.connect (sigc::bind (sigc::ptr_fun (on_cluster_added),
-						 (gpointer) self));
+ 						 (gpointer) self));
   self->priv->connections.push_back (conn);
   conn = core.heap_added.connect (sigc::bind (sigc::ptr_fun (on_heap_added),
-					      (gpointer) self));
+ 					      (gpointer) self));
   self->priv->connections.push_back (conn);
   conn = core.heap_updated.connect (sigc::bind (sigc::ptr_fun (on_heap_updated),
-						(gpointer) self));
+ 						(gpointer) self));
   self->priv->connections.push_back (conn);
   conn = core.heap_removed.connect (sigc::bind (sigc::ptr_fun (on_heap_removed),
-						(gpointer) self));
+ 						(gpointer) self));
 
   self->priv->connections.push_back (conn);
   conn = core.presentity_added.connect (sigc::bind (sigc::ptr_fun (on_presentity_added),
-						    (gpointer) self));
+ 						    (gpointer) self));
   self->priv->connections.push_back (conn);
   conn = core.presentity_updated.connect (sigc::bind (sigc::ptr_fun (on_presentity_updated),
-						      self));
+ 						      self));
   self->priv->connections.push_back (conn);
   conn = core.presentity_removed.connect (sigc::bind (sigc::ptr_fun (on_presentity_removed),
-						      (gpointer) self));
+ 						      (gpointer) self));
   self->priv->connections.push_back (conn);
   conn = core.questions.add_handler (sigc::bind (sigc::ptr_fun (on_handle_questions), (gpointer) self));
   self->priv->connections.push_back (conn);
