@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@
  *                          build the druid.
  */
 
-#include "config.h"
+#include <glib/gi18n.h>
 
 #include "framework/services.h"
 #include "account-core.h"
@@ -141,13 +141,13 @@ set_current_page_complete (GtkAssistant *assistant,
 
 void 
 get_audiooutput_devices_list (Ekiga::ServiceCore *core,
-                                        std::vector<std::string> & device_list);
+                              std::vector<std::string> & device_list);
 void 
 get_audioinput_devices_list (Ekiga::ServiceCore *core,
-                                        std::vector<std::string> & device_list);
+                             std::vector<std::string> & device_list);
 void 
 get_videoinput_devices_list (Ekiga::ServiceCore *core,
-                                        std::vector<std::string> & device_list);
+                             std::vector<std::string> & device_list);
 
 gchar**
 convert_string_list (const std::vector<std::string> & list);
@@ -308,6 +308,12 @@ void on_audiooutput_device_removed_cb (const Ekiga::AudioOutputDevice & device,
   remove_combo_box (GTK_COMBO_BOX (assistant->priv->audio_ringer),  device_string.c_str());
 }
 
+static void kind_of_net_changed_nt (G_GNUC_UNUSED gpointer id,
+                                         GmConfEntry *, 
+                                         gpointer)
+{
+  gm_conf_set_int (GENERAL_KEY "kind_of_net", NET_CUSTOM);
+}
 
 static void
 create_welcome_page (EkigaAssistant *assistant)
@@ -322,7 +328,7 @@ create_welcome_page (EkigaAssistant *assistant)
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
   gtk_widget_show (label);
   gtk_assistant_append_page (GTK_ASSISTANT (assistant), label);
-  gtk_assistant_set_page_title (GTK_ASSISTANT (assistant), label, _("Welcome in Ekiga"));
+  gtk_assistant_set_page_title (GTK_ASSISTANT (assistant), label, _("Welcome to Ekiga"));
   gtk_assistant_set_page_type (GTK_ASSISTANT (assistant), label, GTK_ASSISTANT_PAGE_INTRO);
   gtk_assistant_set_page_header_image (GTK_ASSISTANT (assistant), label, assistant->priv->icon);
   gtk_assistant_set_page_complete (GTK_ASSISTANT (assistant), label, TRUE);
@@ -627,8 +633,8 @@ create_ekiga_net_page (EkigaAssistant *assistant)
 static void
 prepare_ekiga_net_page (EkigaAssistant *assistant)
 {
-  Ekiga::AccountCore *account_core = dynamic_cast<Ekiga::AccountCore *> (assistant->priv->core->get ("account-core"));
-  Ekiga::Account *account = account_core->find_account ("ekiga.net");
+  gmref_ptr<Opal::Bank> bank = assistant->priv->core->get ("opal-account-store");
+  Opal::Account* account = bank->find_account ("ekiga.net");
 
   if (account && !account->get_username ().empty ())
     gtk_entry_set_text (GTK_ENTRY (assistant->priv->username), account->get_username ().c_str ());
@@ -644,19 +650,15 @@ prepare_ekiga_net_page (EkigaAssistant *assistant)
 static void
 apply_ekiga_net_page (EkigaAssistant *assistant)
 {
-  Ekiga::AccountCore *account_core = dynamic_cast<Ekiga::AccountCore *> (assistant->priv->core->get ("account-core"));
-
-  /* Some specific Opal stuff for the Ekiga.net account */
-  Opal::Bank *opal_bank = dynamic_cast<Opal::Bank *> (assistant->priv->core->get ("opal-account-store"));
-  Opal::Account *account = dynamic_cast<Opal::Account *> (account_core->find_account ("ekiga.net"));
-
+  gmref_ptr<Opal::Bank> bank = assistant->priv->core->get ("opal-account-store");
+  Opal::Account* account = bank->find_account ("ekiga.net");
   bool new_account = (account == NULL);
 
   if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (assistant->priv->skip_ekiga_net))) {
 	if (new_account)
-	  opal_bank->new_account (Opal::Account::Ekiga,
-							  gtk_entry_get_text (GTK_ENTRY (assistant->priv->username)),
-							  gtk_entry_get_text (GTK_ENTRY (assistant->priv->password)));
+	  bank->new_account (Opal::Account::Ekiga,
+			     gtk_entry_get_text (GTK_ENTRY (assistant->priv->username)),
+			     gtk_entry_get_text (GTK_ENTRY (assistant->priv->password)));
 	else
 	  account->set_authentication_settings (gtk_entry_get_text (GTK_ENTRY (assistant->priv->username)),
 											gtk_entry_get_text (GTK_ENTRY (assistant->priv->password)));
@@ -695,7 +697,7 @@ create_ekiga_out_page (EkigaAssistant *assistant)
   label = gtk_label_new (NULL);
   text = g_strdup_printf ("<i>%s</i>",
                           _("You can make calls to regular phones and cell numbers worldwide using Ekiga.\n\n"
-                            "To enable this, you need to do three things:\n"
+                            "To enable this, you need to do two things:\n"
                             "- First buy an account at the URL below.\n"
                             "- Then enter your account ID and PIN code.\n"
                             "The service will work only if your account is created using the URL in this dialog.\n"));
@@ -775,8 +777,8 @@ create_ekiga_out_page (EkigaAssistant *assistant)
 static void
 prepare_ekiga_out_page (EkigaAssistant *assistant)
 {
-  Ekiga::AccountCore *account_core = dynamic_cast<Ekiga::AccountCore *> (assistant->priv->core->get ("account-core"));
-  Ekiga::Account *account = account_core->find_account ("sip.diamondcard.us");
+  gmref_ptr<Opal::Bank> account_core = assistant->priv->core->get ("opal-account-store");
+  Opal::Account* account = account_core->find_account ("sip.diamondcard.us");
 
   if (account && !account->get_username ().empty ())
     gtk_entry_set_text (GTK_ENTRY (assistant->priv->dusername), account->get_username ().c_str ());
@@ -792,22 +794,19 @@ prepare_ekiga_out_page (EkigaAssistant *assistant)
 static void
 apply_ekiga_out_page (EkigaAssistant *assistant)
 {
-  Ekiga::AccountCore *account_core = dynamic_cast<Ekiga::AccountCore *> (assistant->priv->core->get ("account-core"));
-
   /* Some specific Opal stuff for the Ekiga.net account */
-  Opal::Bank *opal_bank = dynamic_cast<Opal::Bank *> (assistant->priv->core->get ("opal-account-store"));
-  Opal::Account *account = dynamic_cast<Opal::Account *> (account_core->find_account ("sip.diamondcard.us"));
-
+  gmref_ptr<Opal::Bank> bank = assistant->priv->core->get ("opal-account-store");
+  Opal::Account* account = bank->find_account ("sip.diamondcard.us");
   bool new_account = (account == NULL);
 
   if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (assistant->priv->skip_ekiga_out))) {
 	if (new_account)
-	  opal_bank->new_account (Opal::Account::DiamondCard,
-							  gtk_entry_get_text (GTK_ENTRY (assistant->priv->dusername)),
-							  gtk_entry_get_text (GTK_ENTRY (assistant->priv->dpassword)));
+	  bank->new_account (Opal::Account::DiamondCard,
+			     gtk_entry_get_text (GTK_ENTRY (assistant->priv->dusername)),
+			     gtk_entry_get_text (GTK_ENTRY (assistant->priv->dpassword)));
 	else
 	  account->set_authentication_settings (gtk_entry_get_text (GTK_ENTRY (assistant->priv->dusername)),
-											gtk_entry_get_text (GTK_ENTRY (assistant->priv->dpassword)));
+						gtk_entry_get_text (GTK_ENTRY (assistant->priv->dpassword)));
   }
 }
 
@@ -1077,8 +1076,16 @@ prepare_audio_devices_page (EkigaAssistant *assistant)
   char **array;
 
   ringer = gm_conf_get_string (SOUND_EVENTS_KEY "output_device");
+  if (ringer == NULL)
+    ringer = g_strdup ("Default (PTLIB/ALSA)");
+
   player = gm_conf_get_string (AUDIO_DEVICES_KEY "output_device");
+  if (player == NULL)
+    player = g_strdup ("Default (PTLIB/ALSA)");
+
   recorder = gm_conf_get_string (AUDIO_DEVICES_KEY "input_device");
+  if (recorder == NULL)
+    recorder = g_strdup ("Default (PTLIB/ALSA)");
 
   /* FIXME: We should use DetectDevices, however DetectDevices
    * works only for the currently selected audio and video plugins,
@@ -1190,6 +1197,7 @@ prepare_video_devices_page (EkigaAssistant *assistant)
   update_combo_box (GTK_COMBO_BOX (assistant->priv->video_device),
                     array, current_plugin);
   g_free (array);
+  g_free (current_plugin);
 }
 
 static void
@@ -1212,9 +1220,10 @@ apply_video_devices_page (EkigaAssistant *assistant)
 // FIXME: duplicate to gm_prefs_window_get_video_devices_list
 void 
 get_audiooutput_devices_list (Ekiga::ServiceCore *core,
-                                        std::vector<std::string> & device_list)
+                              std::vector<std::string> & device_list)
 {
-  Ekiga::AudioOutputCore *audiooutput_core = dynamic_cast<Ekiga::AudioOutputCore *> (core->get ("audiooutput-core"));
+  gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core
+    = core->get ("audiooutput-core");
   std::vector <Ekiga::AudioOutputDevice> devices;
 
   device_list.clear();
@@ -1235,9 +1244,10 @@ get_audiooutput_devices_list (Ekiga::ServiceCore *core,
 
 void 
 get_audioinput_devices_list (Ekiga::ServiceCore *core,
-                                        std::vector<std::string> & device_list)
+                             std::vector<std::string> & device_list)
 {
-  Ekiga::AudioInputCore *audioinput_core = dynamic_cast<Ekiga::AudioInputCore *> (core->get ("audioinput-core"));
+  gmref_ptr<Ekiga::AudioInputCore> audioinput_core
+    = core->get ("audioinput-core");
   std::vector <Ekiga::AudioInputDevice> devices;
 
   device_list.clear();
@@ -1260,7 +1270,8 @@ void
 get_videoinput_devices_list (Ekiga::ServiceCore *core,
                                         std::vector<std::string> & device_list)
 {
-  Ekiga::VideoInputCore *videoinput_core = dynamic_cast<Ekiga::VideoInputCore *> (core->get ("videoinput-core"));
+  gmref_ptr<Ekiga::VideoInputCore> videoinput_core
+    = core->get ("videoinput-core");
   std::vector<Ekiga::VideoInputDevice> devices;
 
   device_list.clear();
@@ -1615,9 +1626,12 @@ ekiga_assistant_new (Ekiga::ServiceCore *core)
                     G_CALLBACK (ekiga_assistant_key_press_cb), NULL);
 
   sigc::connection conn;
-  Ekiga::VideoInputCore *videoinput_core = dynamic_cast<Ekiga::VideoInputCore *> (core->get ("videoinput-core"));
-  Ekiga::AudioInputCore *audioinput_core = dynamic_cast<Ekiga::AudioInputCore *> (core->get ("audioinput-core"));
-  Ekiga::AudioOutputCore *audiooutput_core = dynamic_cast<Ekiga::AudioOutputCore *> (core->get ("audiooutput-core"));
+  gmref_ptr<Ekiga::VideoInputCore> videoinput_core
+    = core->get ("videoinput-core");
+  gmref_ptr<Ekiga::AudioInputCore> audioinput_core
+    = core->get ("audioinput-core");
+  gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core
+    = core->get ("audiooutput-core");
 
   conn = videoinput_core->device_added.connect (sigc::bind (sigc::ptr_fun (on_videoinput_device_added_cb), assistant));
   assistant->priv->connections.push_back (conn);
@@ -1634,5 +1648,13 @@ ekiga_assistant_new (Ekiga::ServiceCore *core)
   conn = audiooutput_core->device_removed.connect (sigc::bind (sigc::ptr_fun (on_audiooutput_device_removed_cb), assistant));
   assistant->priv->connections.push_back (conn);
 
+  /* Notifiers for the VIDEO_CODECS_KEY keys */
+  gm_conf_notifier_add (VIDEO_CODECS_KEY "enable_video",
+			kind_of_net_changed_nt, NULL);	     
+  gm_conf_notifier_add (VIDEO_CODECS_KEY "maximum_video_tx_bitrate", 
+			kind_of_net_changed_nt, NULL);
+  gm_conf_notifier_add (VIDEO_CODECS_KEY "temporal_spatial_tradeoff", 
+			kind_of_net_changed_nt, NULL);
+
   return GTK_WIDGET (assistant);
 }
