@@ -1,6 +1,6 @@
  
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -59,12 +59,6 @@
 #include "platform/winpaths.h"
 #endif
 
-#ifdef HAVE_GNOME
-#define FILECHOOSER_BACKEND "gnome-vfs"
-#else
-#define FILECHOOSER_BACKEND "gtk+"
-#endif
-
 
 typedef struct _GmPreferencesWindow
 {
@@ -103,6 +97,13 @@ static void gm_pw_destroy (gpointer prefs_window);
 static GmPreferencesWindow *gm_pw_get_pw (GtkWidget *preferences_window);
 
 
+/* DESCRIPTION  :  / 
+ * BEHAVIOR     :  Builds the sound events list of the preferences window. 
+ * PRE          :  /
+ */
+static void gm_prefs_window_sound_events_list_build (GtkWidget *prefs_window); 
+
+
 /* DESCRIPTION  : /
  * BEHAVIOR     : Adds an update button connected to the given callback to
  * 		  the given GtkBox.
@@ -115,7 +116,7 @@ static GtkWidget *gm_pw_add_update_button (GtkWidget *prefs_window,
 					   GtkWidget *box,
 					   const char *stock_id,
 					   const char *label,
-					   GtkSignalFunc func,
+					   GCallback func,
 					   gchar *tooltip,
 					   gfloat valign,
 					   gpointer data);
@@ -269,15 +270,15 @@ static void audioev_filename_browse_cb (GtkWidget *widget,
 					gpointer data);
 
 
-/* DESCRIPTION  :  This callback is used for the preview of the selected
- *                 image in the file-selector's image
- * BEHAVIOR     :  Update of the file-selector's image.
- * PRE          :  /
+/* DESCRIPTION  :  This callback is called when something changes in the sound
+ *                 events list.
+ * BEHAVIOR     :  It updates the events list widget.
+ * PRE          :  A pointer to the prefs window GMObject.
  */
-/*
-static void image_filename_browse_preview_cb (GtkWidget *selector,
-                                              gpointer data);
-*/
+static void sound_events_list_changed_nt (gpointer id,
+					  GmConfEntry *entry,
+					  gpointer data);
+
 
 /* DESCRIPTION  :  This callback is called by the preview-play button of the
  * 		   selected audio file in the audio file selector.
@@ -320,12 +321,94 @@ gm_pw_get_pw (GtkWidget *preferences_window)
 }
 
 
+static void
+gm_prefs_window_sound_events_list_build (GtkWidget *prefs_window)
+{
+  GmPreferencesWindow *pw = NULL;
+
+  GtkTreeSelection *selection = NULL;
+  GtkTreePath *path = NULL;
+  GtkTreeModel *model = NULL;
+  GtkTreeIter iter, selected_iter;
+
+  bool enabled = FALSE;
+
+  pw = gm_pw_get_pw (prefs_window);
+
+  selection = 
+    gtk_tree_view_get_selection (GTK_TREE_VIEW (pw->sound_events_list));
+
+  if (gtk_tree_selection_get_selected (selection, &model, &selected_iter))
+    path = gtk_tree_model_get_path (model, &selected_iter);
+
+  gtk_list_store_clear (GTK_LIST_STORE (model));
+
+  /* Sound on incoming calls */
+  enabled = gm_conf_get_bool (SOUND_EVENTS_KEY "enable_incoming_call_sound");
+  gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+		      0, enabled,
+		      1, _("Play sound on incoming calls"),
+		      2, SOUND_EVENTS_KEY "incoming_call_sound",
+		      3, SOUND_EVENTS_KEY "enable_incoming_call_sound",
+                      4, "incoming_call_sound",
+		      -1);
+
+  enabled = gm_conf_get_bool (SOUND_EVENTS_KEY "enable_ring_tone_sound");
+  gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+		      0, enabled,
+		      1, _("Play ring tone"),
+		      2, SOUND_EVENTS_KEY "ring_tone_sound",
+		      3, SOUND_EVENTS_KEY "enable_ring_tone_sound",
+                      4, "ring_tone_sound",
+		      -1);
+
+  enabled = gm_conf_get_bool (SOUND_EVENTS_KEY "enable_busy_tone_sound");
+  gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+		      0, enabled,
+		      1, _("Play busy tone"),
+		      2, SOUND_EVENTS_KEY "busy_tone_sound",
+		      3, SOUND_EVENTS_KEY "enable_busy_tone_sound",
+		      4, "busy_tone_sound",
+		      -1);
+
+  enabled = gm_conf_get_bool (SOUND_EVENTS_KEY "enable_new_voicemail_sound");
+  gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+		      0, enabled,
+		      1, _("Play sound for new voice mails"),
+		      2, SOUND_EVENTS_KEY "new_voicemail_sound",
+		      3, SOUND_EVENTS_KEY "enable_new_voicemail_sound",
+		      4, "new_voicemail_sound",
+		      -1);
+  
+  enabled = gm_conf_get_bool (SOUND_EVENTS_KEY "enable_new_message_sound");
+  gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+		      0, enabled,
+		      1, _("Play sound for new instant messages"),
+		      2, SOUND_EVENTS_KEY "new_message_sound",
+		      3, SOUND_EVENTS_KEY "enable_new_message_sound",
+		      4, "new_message_sound",
+		      -1);
+
+  if (!path)
+    path = gtk_tree_path_new_from_string ("0");
+
+  gtk_tree_view_set_cursor (GTK_TREE_VIEW (pw->sound_events_list),
+			    path, NULL, false);
+  gtk_tree_path_free (path);
+}
+
+
 static GtkWidget *
 gm_pw_add_update_button (G_GNUC_UNUSED GtkWidget *prefs_window,
                          GtkWidget *box,
                          const char *stock_id,
                          const char *label,
-                         GtkSignalFunc func,
+                         GCallback func,
                          G_GNUC_UNUSED gchar *tooltip,
                          gfloat valign,
                          gpointer data)
@@ -401,6 +484,13 @@ gm_pw_init_interface_page (GtkWidget *prefs_window,
                                 _("Video Display"), 1, 2);
 
   gnome_prefs_toggle_new (subsection, _("Place windows displaying video _above other windows"), VIDEO_DISPLAY_KEY "stay_on_top", _("Place windows displaying video above other windows during calls"), 0);
+
+  /* Network Settings */
+  subsection = gnome_prefs_subsection_new (prefs_window, container, 
+                                           _("Network Settings"), 1, 2);
+
+  gnome_prefs_toggle_new (subsection, _("Disable network _detection"), NAT_KEY "disable_stun", _("Disable the automatic network setup resulting from the STUN test"), 0);
+
 }
 
 static void
@@ -517,9 +607,8 @@ gm_pw_init_sound_events_page (GtkWidget *prefs_window,
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 2);
 
   fsbutton =
-    gtk_file_chooser_button_new_with_backend (_("Choose a sound"),
-                                              GTK_FILE_CHOOSER_ACTION_OPEN,
-                                              FILECHOOSER_BACKEND);
+    gtk_file_chooser_button_new (_("Choose a sound"),
+                                 GTK_FILE_CHOOSER_ACTION_OPEN);
   gtk_box_pack_start (GTK_BOX (hbox), fsbutton, TRUE, TRUE, 2);
 
   filefilter = gtk_file_filter_new ();
@@ -676,21 +765,21 @@ gm_pw_init_audio_devices_page (GtkWidget *prefs_window,
   gm_prefs_window_get_audiooutput_devices_list (pw->core, device_list);
   array = gm_prefs_window_convert_string_list(device_list);
   pw->sound_events_output = 
-    gnome_prefs_string_option_menu_new (subsection, _("Ringing Device"), (const gchar **)array, SOUND_EVENTS_KEY "output_device", _("Select the ringing audio device to use"), 0);
+    gnome_prefs_string_option_menu_new (subsection, _("Ringing Device"), (const gchar **)array, SOUND_EVENTS_KEY "output_device", _("Select the ringing audio device to use"), 0, "Default (PTLIB/ALSA)");
   pw->audio_player =
-    gnome_prefs_string_option_menu_new (subsection, _("Output device:"), (const gchar **)array, AUDIO_DEVICES_KEY "output_device", _("Select the audio output device to use"), 1);
+    gnome_prefs_string_option_menu_new (subsection, _("Output device:"), (const gchar **)array, AUDIO_DEVICES_KEY "output_device", _("Select the audio output device to use"), 1, "Default (PTLIB/ALSA)");
   g_free (array);
 
   /* The recorder */
   gm_prefs_window_get_audioinput_devices_list (pw->core, device_list);
   array = gm_prefs_window_convert_string_list(device_list);
   pw->audio_recorder =
-    gnome_prefs_string_option_menu_new (subsection, _("Input device:"), (const gchar **)array, AUDIO_DEVICES_KEY "input_device", _("Select the audio input device to use"), 2);
+    gnome_prefs_string_option_menu_new (subsection, _("Input device:"), (const gchar **)array, AUDIO_DEVICES_KEY "input_device", _("Select the audio input device to use"), 2, "Default (PTLIB/ALSA)");
   g_free (array);
 
 
   /* That button will refresh the device list */
-  gm_pw_add_update_button (prefs_window, container, GTK_STOCK_REFRESH, _("_Detect devices"), GTK_SIGNAL_FUNC (refresh_devices_list_cb), _("Click here to refresh the device list."), 1, prefs_window);
+  gm_pw_add_update_button (prefs_window, container, GTK_STOCK_REFRESH, _("_Detect devices"), G_CALLBACK (refresh_devices_list_cb), _("Click here to refresh the device list."), 1, prefs_window);
 }
 
 
@@ -698,7 +787,8 @@ void
 gm_prefs_window_get_videoinput_devices_list (Ekiga::ServiceCore *core,
                                         std::vector<std::string> & device_list)
 {
-  Ekiga::VideoInputCore *videoinput_core = dynamic_cast<Ekiga::VideoInputCore *> (core->get ("videoinput-core"));
+  gmref_ptr<Ekiga::VideoInputCore> videoinput_core
+    = core->get ("videoinput-core");
   std::vector <Ekiga::VideoInputDevice> devices;
 
   device_list.clear();
@@ -720,7 +810,8 @@ void
 gm_prefs_window_get_audiooutput_devices_list (Ekiga::ServiceCore *core,
                                         std::vector<std::string> & device_list)
 {
-  Ekiga::AudioOutputCore *audiooutput_core = dynamic_cast<Ekiga::AudioOutputCore *> (core->get ("audiooutput-core"));
+  gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core
+    = core->get ("audiooutput-core");
   std::vector <Ekiga::AudioOutputDevice> devices;
 
   std::string device_string;
@@ -745,7 +836,8 @@ void
 gm_prefs_window_get_audioinput_devices_list (Ekiga::ServiceCore *core,
                                         std::vector<std::string> & device_list)
 {
-  Ekiga::AudioInputCore *audioinput_core = dynamic_cast<Ekiga::AudioInputCore *> (core->get ("audioinput-core"));
+  gmref_ptr<Ekiga::AudioInputCore> audioinput_core
+    = core->get ("audioinput-core");
   std::vector <Ekiga::AudioInputDevice> devices;
 
   device_list.clear();
@@ -833,7 +925,7 @@ gm_pw_init_video_devices_page (GtkWidget *prefs_window,
   gm_prefs_window_get_videoinput_devices_list (pw->core, device_list);
   array = gm_prefs_window_convert_string_list(device_list);
   pw->video_device =
-    gnome_prefs_string_option_menu_new (subsection, _("Input device:"), (const gchar **)array, VIDEO_DEVICES_KEY "input_device", _("Select the video input device to use. If an error occurs when using this device a test picture will be transmitted."), 0);
+    gnome_prefs_string_option_menu_new (subsection, _("Input device:"), (const gchar **)array, VIDEO_DEVICES_KEY "input_device", _("Select the video input device to use. If an error occurs when using this device a test picture will be transmitted."), 0, NULL);
   g_free (array);
 
   /* Video Channel */
@@ -843,62 +935,8 @@ gm_pw_init_video_devices_page (GtkWidget *prefs_window,
 
   gnome_prefs_int_option_menu_new (subsection, _("Format:"), video_format, VIDEO_DEVICES_KEY "format", _("Select the format for video cameras (does not apply to most USB cameras)"), 2);
 
-  /* The file selector button */
-  /* FIXME disabled for now
-  label = gtk_label_new (_("Image:"));
-
-  button = 
-    gtk_file_chooser_button_new_with_backend (_("Choose a Picture"),
-                                              GTK_FILE_CHOOSER_ACTION_OPEN,
-                                              FILECHOOSER_BACKEND);
-
-  preview_image_frame = gtk_frame_new (_("Preview"));
-  preview_image = gtk_image_new ();
-  gtk_container_add (GTK_CONTAINER (preview_image_frame), preview_image);
-  gtk_widget_set_size_request (preview_image, 256, 256);
-  gtk_widget_show (preview_image);
-  gtk_file_chooser_set_preview_widget (GTK_FILE_CHOOSER (button),
-                                       preview_image_frame);
-
-
-  filefilter = gtk_file_filter_new ();
-  gtk_file_filter_set_name (filefilter, _("Images"));
-  gtk_file_filter_add_pixbuf_formats (filefilter);
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (button), filefilter);
-
-  g_signal_connect (G_OBJECT (button), "update-preview",
-                    G_CALLBACK (image_filename_browse_preview_cb),
-                    (gpointer) preview_image);
-
-  conf_image = gm_conf_get_string (VIDEO_DEVICES_KEY "image");
-  if (!conf_image || (!strcmp (conf_image, ""))) {
-    g_free (conf_image);
-    conf_image = NULL;
-  }
-
-  if (conf_image)
-    gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (button), conf_image);
-  g_free (conf_image);
-
-  gtk_table_attach (GTK_TABLE (subsection), button, 1, 2, 4, 5,
-                    (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
-                    (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
-                    0, GNOMEMEETING_PAD_SMALL);
-
-  gtk_table_attach (GTK_TABLE (subsection), label, 0, 1, 4, 5,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (GTK_FILL),
-                    0, 0);
-
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-  gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-
-  g_signal_connect_after (G_OBJECT (button), "selection-changed",
-                          G_CALLBACK (image_filename_browse_cb),
-                          (gpointer) VIDEO_DEVICES_KEY "image");
-  */
   /* That button will refresh the device list */
-  gm_pw_add_update_button (prefs_window, container, GTK_STOCK_REFRESH, _("_Detect devices"), GTK_SIGNAL_FUNC (refresh_devices_list_cb), _("Click here to refresh the device list."), 1, prefs_window);
+  gm_pw_add_update_button (prefs_window, container, GTK_STOCK_REFRESH, _("_Detect devices"), G_CALLBACK (refresh_devices_list_cb), _("Click here to refresh the device list."), 1, prefs_window);
 
   for (i=0; i< NB_VIDEO_SIZES; i++) {
 
@@ -943,7 +981,7 @@ gm_pw_init_audio_codecs_page (GtkWidget *prefs_window,
   
   gnome_prefs_toggle_new (subsection, _("Enable echo can_celation"), AUDIO_CODECS_KEY "enable_echo_cancelation", _("If enabled, use echo cancelation."), 1);
 
-  gnome_prefs_spin_new (subsection, _("Maximum _jitter buffer (in ms):"), AUDIO_CODECS_KEY "maximum_jitter_buffer", _("The maximum jitter buffer size for audio reception (in ms)."), 30.0, 2000.0, 50.0, 2, NULL, true);
+  gnome_prefs_spin_new (subsection, _("Maximum _jitter buffer (in ms):"), AUDIO_CODECS_KEY "maximum_jitter_buffer", _("The maximum jitter buffer size for audio reception (in ms)."), 20.0, 2000.0, 50.0, 2, NULL, true);
 }
 
 
@@ -997,31 +1035,6 @@ refresh_devices_list_cb (G_GNUC_UNUSED GtkWidget *widget,
 }
 
 
-/*
-static void
-image_filename_browse_cb (GtkWidget *b,
-			  gpointer data)
-{
-  char *filename = NULL;
-  char *current_filename = NULL;
-
-  g_return_if_fail (data != NULL);
-  filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (b));
-
-  if (filename == NULL)
-    return;
-  
-  current_filename = gm_conf_get_string ((gchar *) data);
-  if (current_filename && strcmp (current_filename, filename))
-    gm_conf_set_string ((gchar *) data, (gchar *) filename);
-
-  g_free (filename);
-  g_free (current_filename);
-
-  g_signal_emit_by_name (G_OBJECT (b), "update-preview");
-}
-*/
-
 static void
 audioev_filename_browse_cb (GtkWidget *b,
                             gpointer data)
@@ -1066,6 +1079,24 @@ audioev_filename_browse_cb (GtkWidget *b,
 }
 
 
+static void
+sound_events_list_changed_nt (G_GNUC_UNUSED gpointer id,
+			      GmConfEntry *entry,
+			      G_GNUC_UNUSED gpointer data)
+{
+  GtkWidget *prefs_window;
+
+  if (gm_conf_entry_get_type (entry) == GM_CONF_STRING
+      || gm_conf_entry_get_type (entry) == GM_CONF_BOOL) {
+   
+    prefs_window = GnomeMeeting::Process ()->GetPrefsWindow (false);
+    if (prefs_window) {
+      gm_prefs_window_sound_events_list_build (prefs_window);
+    }
+  }
+}
+
+
 static void
 sound_event_clicked_cb (GtkTreeSelection *selection,
 			gpointer data)
@@ -1119,7 +1150,9 @@ sound_event_play_cb (G_GNUC_UNUSED GtkWidget *widget,
   
   g_return_if_fail (data != NULL);
   pw = gm_pw_get_pw (GTK_WIDGET (data));
-  
+
+  g_return_if_fail (data != NULL);
+
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (pw->sound_events_list));
 
   if (gtk_tree_selection_get_selected (selection, &model, &selected_iter)) {
@@ -1128,7 +1161,7 @@ sound_event_play_cb (G_GNUC_UNUSED GtkWidget *widget,
 
     //FIXME
     Ekiga::ServiceCore *core = GnomeMeeting::Process ()->GetServiceCore (); 
-    Ekiga::AudioOutputCore *audiooutput_core = dynamic_cast<Ekiga::AudioOutputCore*> (core->get ("audiooutput-core"));
+    gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core = core->get ("audiooutput-core");
 
     if (sound_event) { 
       audiooutput_core->play_event(sound_event);
@@ -1137,6 +1170,7 @@ sound_event_play_cb (G_GNUC_UNUSED GtkWidget *widget,
   }
 }
 
+
 static void
 sound_event_toggled_cb (G_GNUC_UNUSED GtkCellRendererToggle *cell,
 			gchar *path_str,
@@ -1166,44 +1200,6 @@ sound_event_toggled_cb (G_GNUC_UNUSED GtkCellRendererToggle *cell,
 }
 
 
-/*
-static void
-image_filename_browse_preview_cb (GtkWidget *selector,
-				  gpointer data)
-{
-  GtkWidget *previewer = NULL;
-  char *filename = NULL;
-  GdkPixbuf *pixbuf = NULL;
-
-  g_return_if_fail (data != NULL);
-
-  previewer = GTK_WIDGET (data);
-
-  filename =
-    gtk_file_chooser_get_preview_filename (GTK_FILE_CHOOSER (selector));
-  if (!filename)
-    filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (selector));
-
-  if (!filename)
-    filename = gm_conf_get_string (VIDEO_DEVICES_KEY "image");
-
-  if (filename)
-    pixbuf = gdk_pixbuf_new_from_file_at_size (filename,
-					       256, 256,
-					       NULL);
-
-  g_free (filename);
-
-  gtk_image_set_from_pixbuf (GTK_IMAGE (previewer), pixbuf);
-
-  if (pixbuf) g_object_unref (pixbuf);
-
-  gtk_file_chooser_set_preview_widget_active (GTK_FILE_CHOOSER (selector),
-					      TRUE);
-}
-*/
-
-
 static void
 audioev_filename_browse_play_cb (GtkWidget* /* playbutton */,
 				 gpointer data)
@@ -1212,13 +1208,14 @@ audioev_filename_browse_play_cb (GtkWidget* /* playbutton */,
 
   //FIXME
   Ekiga::ServiceCore *core = GnomeMeeting::Process ()->GetServiceCore (); 
-  Ekiga::AudioOutputCore *audiooutput_core = dynamic_cast<Ekiga::AudioOutputCore *> (core->get ("audiooutput-core"));
+  gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core
+    = core->get ("audiooutput-core");
 
   gchar* file_name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (data));
   std::string file_name_string = file_name;
   audiooutput_core->play_file(file_name_string);
 
-   g_free (file_name);
+  g_free (file_name);
 }
 
 void on_videoinput_device_added_cb (const Ekiga::VideoInputDevice & device, bool isDesired, GtkWidget *prefs_window)
@@ -1289,10 +1286,12 @@ gm_prefs_window_update_devices_list (GtkWidget *prefs_window)
   array = gm_prefs_window_convert_string_list(device_list);
   gnome_prefs_string_option_menu_update (pw->audio_player,
  					 (const gchar **)array,
- 					 AUDIO_DEVICES_KEY "output_device");
-   gnome_prefs_string_option_menu_update (pw->sound_events_output,
- 					 (const gchar **)array,
- 					 SOUND_EVENTS_KEY "output_device");
+ 					 AUDIO_DEVICES_KEY "output_device",
+                                         "Default (PTLIB/ALSA)");
+  gnome_prefs_string_option_menu_update (pw->sound_events_output,
+                                         (const gchar **)array,
+                                         SOUND_EVENTS_KEY "output_device",
+                                         "Default (PTLIB/ALSA)");
   g_free (array);
 
   /* The recorder */
@@ -1300,7 +1299,8 @@ gm_prefs_window_update_devices_list (GtkWidget *prefs_window)
   array = gm_prefs_window_convert_string_list(device_list);
   gnome_prefs_string_option_menu_update (pw->audio_recorder,
  					 (const gchar **)array,
- 					 AUDIO_DEVICES_KEY "input_device");
+ 					 AUDIO_DEVICES_KEY "input_device",
+                                         "Default (PTLIB/ALSA)");
   g_free (array);
 
 
@@ -1309,93 +1309,12 @@ gm_prefs_window_update_devices_list (GtkWidget *prefs_window)
   array = gm_prefs_window_convert_string_list(device_list);
   gnome_prefs_string_option_menu_update (pw->video_device,
 					 (const gchar **)array,
-					 VIDEO_DEVICES_KEY "input_device");
+					 VIDEO_DEVICES_KEY "input_device",
+                                         NULL);
   g_free (array);
 }
 
 
-void
-gm_prefs_window_sound_events_list_build (GtkWidget *prefs_window)
-{
-  GmPreferencesWindow *pw = NULL;
-
-  GtkTreeSelection *selection = NULL;
-  GtkTreePath *path = NULL;
-  GtkTreeModel *model = NULL;
-  GtkTreeIter iter, selected_iter;
-
-  bool enabled = FALSE;
-
-  pw = gm_pw_get_pw (prefs_window);
-
-  selection = 
-    gtk_tree_view_get_selection (GTK_TREE_VIEW (pw->sound_events_list));
-
-  if (gtk_tree_selection_get_selected (selection, &model, &selected_iter))
-    path = gtk_tree_model_get_path (model, &selected_iter);
-
-  gtk_list_store_clear (GTK_LIST_STORE (model));
-
-  /* Sound on incoming calls */
-  enabled = gm_conf_get_bool (SOUND_EVENTS_KEY "enable_incoming_call_sound");
-  gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-		      0, enabled,
-		      1, _("Play sound on incoming calls"),
-		      2, SOUND_EVENTS_KEY "incoming_call_sound",
-		      3, SOUND_EVENTS_KEY "enable_incoming_call_sound",
-                      4, "incoming_call_sound",
-		      -1);
-
-  enabled = gm_conf_get_bool (SOUND_EVENTS_KEY "enable_ring_tone_sound");
-  gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-		      0, enabled,
-		      1, _("Play ring tone"),
-		      2, SOUND_EVENTS_KEY "ring_tone_sound",
-		      3, SOUND_EVENTS_KEY "enable_ring_tone_sound",
-                      4, "ring_tone_sound",
-		      -1);
-
-  enabled = gm_conf_get_bool (SOUND_EVENTS_KEY "enable_busy_tone_sound");
-  gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-		      0, enabled,
-		      1, _("Play busy tone"),
-		      2, SOUND_EVENTS_KEY "busy_tone_sound",
-		      3, SOUND_EVENTS_KEY "enable_busy_tone_sound",
-		      4, "busy_tone_sound",
-		      -1);
-
-  enabled = gm_conf_get_bool (SOUND_EVENTS_KEY "enable_new_voicemail_sound");
-  gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-		      0, enabled,
-		      1, _("Play sound for new voice mails"),
-		      2, SOUND_EVENTS_KEY "new_voicemail_sound",
-		      3, SOUND_EVENTS_KEY "enable_new_voicemail_sound",
-		      4, "new_voicemail_sound",
-		      -1);
-  
-  enabled = gm_conf_get_bool (SOUND_EVENTS_KEY "enable_new_message_sound");
-  gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-		      0, enabled,
-		      1, _("Play sound for new instant messages"),
-		      2, SOUND_EVENTS_KEY "new_message_sound",
-		      3, SOUND_EVENTS_KEY "enable_new_message_sound",
-		      4, "new_message_sound",
-		      -1);
-
-  if (!path)
-    path = gtk_tree_path_new_from_string ("0");
-
-  gtk_tree_view_set_cursor (GTK_TREE_VIEW (pw->sound_events_list),
-			    path, NULL, false);
-  gtk_tree_path_free (path);
-}
-
-
 GtkWidget *
 gm_prefs_window_new (Ekiga::ServiceCore *core)
 {
@@ -1490,9 +1409,12 @@ gm_prefs_window_new (Ekiga::ServiceCore *core)
 		    G_CALLBACK (delete_window_cb), NULL);
 
   sigc::connection conn;
-  Ekiga::VideoInputCore *videoinput_core = dynamic_cast<Ekiga::VideoInputCore *> (core->get ("videoinput-core"));
-  Ekiga::AudioInputCore *audioinput_core = dynamic_cast<Ekiga::AudioInputCore *> (core->get ("audioinput-core"));
-  Ekiga::AudioOutputCore *audiooutput_core = dynamic_cast<Ekiga::AudioOutputCore *> (core->get ("audiooutput-core"));
+  gmref_ptr<Ekiga::VideoInputCore> videoinput_core
+    = core->get ("videoinput-core");
+  gmref_ptr<Ekiga::AudioInputCore> audioinput_core
+    = core->get ("audioinput-core");
+  gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core
+    = core->get ("audiooutput-core");
 
   conn = videoinput_core->device_added.connect (sigc::bind (sigc::ptr_fun (on_videoinput_device_added_cb), window));
   pw->connections.push_back (conn);
@@ -1508,6 +1430,38 @@ gm_prefs_window_new (Ekiga::ServiceCore *core)
   pw->connections.push_back(conn);
   conn = audiooutput_core->device_removed.connect (sigc::bind (sigc::ptr_fun (on_audiooutput_device_removed_cb), window));
   pw->connections.push_back (conn);
+
+
+  /* Connect notifiers for SOUND_EVENTS_KEY keys */
+  gm_conf_notifier_add (SOUND_EVENTS_KEY "enable_incoming_call_sound", 
+			sound_events_list_changed_nt, NULL);
+  
+  gm_conf_notifier_add (SOUND_EVENTS_KEY "incoming_call_sound",
+			sound_events_list_changed_nt, NULL);
+
+  gm_conf_notifier_add (SOUND_EVENTS_KEY "enable_ring_tone_sound", 
+			sound_events_list_changed_nt, NULL);
+  
+  gm_conf_notifier_add (SOUND_EVENTS_KEY "ring_tone_sound", 
+			sound_events_list_changed_nt, NULL);
+  
+  gm_conf_notifier_add (SOUND_EVENTS_KEY "enable_busy_tone_sound", 
+			sound_events_list_changed_nt, NULL);
+  
+  gm_conf_notifier_add (SOUND_EVENTS_KEY "busy_tone_sound",
+			sound_events_list_changed_nt, NULL);
+  
+  gm_conf_notifier_add (SOUND_EVENTS_KEY "enable_new_voicemail_sound", 
+			sound_events_list_changed_nt, NULL);
+  
+  gm_conf_notifier_add (SOUND_EVENTS_KEY "new_voicemail_sound",
+			sound_events_list_changed_nt, NULL);
+
+  gm_conf_notifier_add (SOUND_EVENTS_KEY "enable_new_message_sound",
+			sound_events_list_changed_nt, NULL);
+
+  gm_conf_notifier_add (SOUND_EVENTS_KEY "new_message_sound",
+			sound_events_list_changed_nt, NULL);
+
   return window;
 }
-
